@@ -29,3 +29,12 @@ def is_command(update):
             return False
 
     return check_entities(entities)
+
+def is_start_command(update):
+    if not is_command(update):
+        return False
+    else:
+        if update.message.text == '/start':
+            return True
+        else:
+            return False
