@@ -118,3 +118,9 @@ class TestStateMethods(unittest.TestCase):
 
         state = MyCustomState()
         self.assertEqual(state.state_name, 'MyCustomState')
+
+    def test_classname(self):
+        class MyCustomState(BaseState):
+            pass
+        self.assertEqual(MyCustomState.classname(), 'MyCustomState')
+
